@@ -11,7 +11,8 @@ use std::path::{Path, PathBuf};
 use std::process::Command;
 use std::str;
 use std::sync::{Arc, Once};
-use std::time::Instant;
+#[cfg(feature = "timeout")]
+use std::time::{Duration, Instant};
 
 // Include a copy of the sh function, because we have a lot of old tests that
 // use it, and it's a lot easier than managing a circular dependency between
@@ -420,7 +421,7 @@ fn test_env_remove_case_sensitivity() {
     // Set an environment variable in the parent. Note that it's important that
     // no other tests use this variable name, because the test runner is
     // multithreaded.
-    let var_name = "TEST_ENV_REMOVE_CASE_SENSITIVITY";
+    let var_name = "TeSt_EnV_rEmOvE_cAsE_sEnSiTiViTy";
     env::set_var(var_name, "abc123");
 
     // Run a command that tries to clear the same variable, but in lowercase.
@@ -449,6 +450,130 @@ fn test_env_remove_case_sensitivity() {
     }
 }
 
+#[test]
+fn test_env_case_preserving() {
+    // Even on Windows, environment variable names are case-preserving. Also, overwriting an
+    // existing env var with a new value does *not* change the casing of the name. (To do that, you
+    // have to remove it first.)
+    let var_name = "TeSt_EnV_cAsE_pReSeRvInG";
+    let var_value = "A unique value that no other var in the environment has. Banana.";
+
+    // Read the name of that variable as seen by a child process. Case should be preserved.
+    assert_eq!(
+        cmd!(path_to_exe("print_env_name"), var_value)
+            .env(var_name, var_value)
+            .read()
+            .unwrap(),
+        var_name,
+    );
+
+    // Use .env() twice, the second time with a different casing. On Unix that's a distinct
+    // variable, and the first var is unchanged. On Windows the value of the first var is changed,
+    // but the name is not.
+    let new_value = "Another unique value that no other var in the environment has. Rutabaga.";
+    #[cfg(windows)]
+    {
+        // No variable has the original value.
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), var_value)
+                // Note: outer modifiers are applied before inner ones.
+                .env(var_name.to_lowercase(), new_value)
+                .env(var_name, var_value)
+                .read()
+                .unwrap(),
+            "",
+        );
+        // The variable with the new value still has the original casing.
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), new_value)
+                // Note: outer modifiers are applied before inner ones.
+                .env(var_name.to_lowercase(), new_value)
+                .env(var_name, var_value)
+                .read()
+                .unwrap(),
+            var_name,
+        );
+        // But doing a removal (in any casing) in between makes the new casing visible.
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), new_value)
+                // Note: outer modifiers are applied before inner ones.
+                .env(var_name.to_lowercase(), new_value)
+                .env_remove(var_name.to_uppercase())
+                .env(var_name, var_value)
+                .read()
+                .unwrap(),
+            var_name.to_lowercase(),
+        );
+    }
+    #[cfg(not(windows))]
+    {
+        // The original variable and the new variable are distinct.
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), var_value)
+                .env(var_name, var_value)
+                .env(var_name.to_lowercase(), new_value)
+                .read()
+                .unwrap(),
+            var_name,
+        );
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), new_value)
+                .env(var_name, var_value)
+                .env(var_name.to_lowercase(), new_value)
+                .read()
+                .unwrap(),
+            var_name.to_lowercase(),
+        );
+    }
+
+    // Double check that env vars in the actual OS environment (as opposed to our `.env()`) behave
+    // the same way. (Do this last so that they're not visible to the tests above.)
+    env::set_var(var_name, var_value);
+    env::set_var(var_name.to_lowercase(), new_value);
+    #[cfg(windows)]
+    {
+        // No variable has the original value.
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), var_value)
+                .read()
+                .unwrap(),
+            "",
+        );
+        // The variable with the new value still has the original casing.
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), new_value)
+                .read()
+                .unwrap(),
+            var_name,
+        );
+        // But doing a removal (in any casing) in between makes the new casing visible.
+        env::remove_var(var_name.to_uppercase());
+        env::set_var(var_name.to_lowercase(), new_value);
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), new_value)
+                .read()
+                .unwrap(),
+            var_name.to_lowercase(),
+        );
+    }
+    #[cfg(not(windows))]
+    {
+        // The original variable and the new variable are distinct.
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), var_value)
+                .read()
+                .unwrap(),
+            var_name,
+        );
+        assert_eq!(
+            cmd!(path_to_exe("print_env_name"), new_value)
+                .read()
+                .unwrap(),
+            var_name.to_lowercase(),
+        );
+    }
+}
+
 #[test]
 fn test_broken_pipe() {
     // If the input writing thread fills up its pipe buffer, writing will block. If the process
@@ -528,18 +653,22 @@ fn test_kill_with_grandchild_stderr_capture() -> io::Result<()> {
     // Kill() the child. This does not wait.
     reader.kill()?;
 
-    // At this point .try_wait() should still return Ok(None), because the stderr capture thread is
-    // still waiting. It won't exit until the grandchild exits ("forever" i.e. in one day). If we
-    // try to join IO threads, this will not return. Loop on this for 100ms to be sure it waits.
-    let start_time = Instant::now();
-    while Instant::now()
-        .saturating_duration_since(start_time)
-        .as_millis()
-        < 100
+    // .wait_timeout() should block until the timeout expires and then return Ok(None), because the
+    // stderr capture thread is still running. Check the clock to make sure it doesn't return too
+    // quickly. (wait_timeout calls wait_deadline internally, so this effectively tests both.)
+    #[cfg(feature = "timeout")]
     {
-        assert!(reader.try_wait()?.is_none());
+        let start = Instant::now();
+        assert!(reader
+            .handle
+            .wait_timeout(Duration::from_millis(100))?
+            .is_none());
+        assert!(Instant::now() - start > Duration::from_millis(50));
     }
 
+    // .try_wait() should also return Ok(None).
+    assert!(reader.try_wait()?.is_none());
+
     Ok(())
 }
 
@@ -571,18 +700,22 @@ fn test_kill_with_grandchild_stdin_bytes() -> io::Result<()> {
     // Kill() the child. This does not wait.
     reader.kill()?;
 
-    // At this point .try_wait() should still return Ok(None), because the stdin bytes thread is
-    // still waiting. It won't exit until the grandchild exits ("forever" i.e. in one day). If we
-    // try to join IO threads, this will not return. Loop on this for 100ms to be sure it waits.
-    let start_time = Instant::now();
-    while Instant::now()
-        .saturating_duration_since(start_time)
-        .as_millis()
-        < 100
+    // .wait_timeout() should block until the timeout expires and then return Ok(None), because the
+    // stdin bytes thread is still running. Check the clock to make sure it doesn't return too
+    // quickly. (wait_timeout calls wait_deadline internally, so this effectively tests both.)
+    #[cfg(feature = "timeout")]
     {
-        assert!(reader.try_wait()?.is_none());
+        let start = Instant::now();
+        assert!(reader
+            .handle
+            .wait_timeout(Duration::from_millis(100))?
+            .is_none());
+        assert!(Instant::now() - start > Duration::from_millis(50));
     }
 
+    // .try_wait() should also return Ok(None).
+    assert!(reader.try_wait()?.is_none());
+
     Ok(())
 }
 
@@ -740,3 +873,28 @@ fn test_zombies_reaped() -> io::Result<()> {
 
     Ok(())
 }
+
+#[test]
+#[cfg(feature = "timeout")]
+fn test_wait_timeout_and_deadline() -> io::Result<()> {
+    // Use a pipe as a poor man's &&.
+    let handle = cmd!(path_to_exe("sleep"), "0.250")
+        .pipe(cmd!(path_to_exe("echo"), "hi"))
+        .stdout_capture()
+        .start()
+        .unwrap();
+
+    assert!(handle.wait_timeout(Duration::from_millis(1))?.is_none());
+    assert!(handle
+        .wait_deadline(Instant::now() + Duration::from_millis(1))?
+        .is_none());
+    let output1 = handle
+        .wait_timeout(Duration::from_millis(10_000))?
+        .expect("should exit");
+    let output2 = handle
+        .wait_deadline(Instant::now() + Duration::from_millis(10_000))?
+        .expect("should exit");
+    assert_eq!(output1, output2);
+    assert_eq!(output1.stdout, b"hi\n");
+    Ok(())
+}
