@@ -76,11 +76,7 @@ use hashbrown::hash_table;
 /// # }
 /// ```
 #[derive(Clone)]
-pub struct BiHashMap<
-    T: BiHashItem,
-    S = DefaultHashBuilder,
-    A: Allocator = Global,
-> {
+pub struct BiHashMap<T, S = DefaultHashBuilder, A: Allocator = Global> {
     pub(super) items: ItemSet<T, A>,
     // Invariant: the values (usize) in these tables are valid indexes into
     // `items`, and are a 1:1 mapping.
@@ -135,7 +131,7 @@ impl<T: BiHashItem> BiHashMap<T> {
     /// ```
     #[inline]
     pub fn new() -> Self {
-        Self { items: ItemSet::default(), tables: BiHashMapTables::default() }
+        Self { items: ItemSet::new(), tables: BiHashMapTables::default() }
     }
 
     /// Creates a new `BiHashMap` with the given capacity.
@@ -218,7 +214,7 @@ impl<T: BiHashItem, S: Clone + BuildHasher> BiHashMap<T, S> {
     /// ```
     pub fn with_hasher(hasher: S) -> Self {
         Self {
-            items: ItemSet::default(),
+            items: ItemSet::new(),
             tables: BiHashMapTables::with_capacity_and_hasher_in(
                 0,
                 hasher,
