@@ -7,6 +7,8 @@ mod daft_impls;
 mod entry;
 pub(crate) mod imp;
 mod iter;
+#[cfg(feature = "proptest")]
+mod proptest_impls;
 mod ref_mut;
 #[cfg(feature = "schemars08")]
 mod schemars_impls;
@@ -20,5 +22,7 @@ pub use daft_impls::Diff;
 pub use entry::{Entry, OccupiedEntry, VacantEntry};
 pub use imp::IdOrdMap;
 pub use iter::{IntoIter, Iter, IterMut};
+#[cfg(feature = "proptest")]
+pub use proptest_impls::{IdOrdMapStrategy, IdOrdMapValueTree, prop_strategy};
 pub use ref_mut::RefMut;
 pub use trait_defs::IdOrdItem;
