@@ -56,6 +56,39 @@ fn debug_impls() {
     );
 }
 
+#[test]
+fn debug_impls_borrowed() {
+    let before = bi_hash_map! {
+        HashBuilder;
+        BorrowedItem { key1: "a", key2: b"b0", key3: Path::new("path0") },
+        BorrowedItem { key1: "b", key2: b"b1", key3: Path::new("path1") },
+        BorrowedItem { key1: "c", key2: b"b2", key3: Path::new("path2") },
+    };
+
+    assert_eq!(
+        format!("{before:?}"),
+        r#"{{k1: "a", k2: [98, 48]}: BorrowedItem { key1: "a", key2: [98, 48], key3: "path0" }, {k1: "c", k2: [98, 50]}: BorrowedItem { key1: "c", key2: [98, 50], key3: "path2" }, {k1: "b", k2: [98, 49]}: BorrowedItem { key1: "b", key2: [98, 49], key3: "path1" }}"#
+    );
+
+    #[cfg(feature = "daft")]
+    {
+        use daft::Diffable;
+
+        let after = bi_hash_map! {
+            HashBuilder;
+            BorrowedItem { key1: "a", key2: b"b0", key3: Path::new("path0") },
+            BorrowedItem { key1: "c", key2: b"b3", key3: Path::new("path3") },
+            BorrowedItem { key1: "d", key2: b"b4", key3: Path::new("path4") },
+        };
+
+        let diff = before.diff(&after).by_unique();
+        assert_eq!(
+            format!("{diff:?}"),
+            r#"Diff { common: {{k1: "a", k2: [98, 48]}: IdLeaf { before: BorrowedItem { key1: "a", key2: [98, 48], key3: "path0" }, after: BorrowedItem { key1: "a", key2: [98, 48], key3: "path0" } }}, added: {{k1: "d", k2: [98, 52]}: BorrowedItem { key1: "d", key2: [98, 52], key3: "path4" }, {k1: "c", k2: [98, 51]}: BorrowedItem { key1: "c", key2: [98, 51], key3: "path3" }}, removed: {{k1: "c", k2: [98, 50]}: BorrowedItem { key1: "c", key2: [98, 50], key3: "path2" }, {k1: "b", k2: [98, 49]}: BorrowedItem { key1: "b", key2: [98, 49], key3: "path1" }} }"#
+        );
+    }
+}
+
 #[test]
 fn with_capacity() {
     let map = BiHashMap::<TestItem, HashBuilder>::with_capacity_and_hasher(
@@ -105,7 +138,7 @@ fn test_insert_unique() {
 
         // Test that the RefMut Debug impl looks good.
         assert!(
-            format!("{:?}", e1).starts_with(
+            format!("{e1:?}").starts_with(
                 r#"TestItem { key1: 0, key2: 'a', key3: "x", value: "v""#,
             ),
             "RefMut Debug impl should forward to TestItem"
@@ -580,7 +613,7 @@ fn borrowed_item() {
     fn fmt_debug(
         map: &BiHashMap<BorrowedItem<'_>, HashBuilder, Alloc>,
     ) -> String {
-        format!("{:?}", map)
+        format!("{map:?}")
     }
 
     static DEBUG_OUTPUT: &str = "{{k1: \"foo\", k2: [102, 111, 111]}: BorrowedItem { \
@@ -588,7 +621,7 @@ fn borrowed_item() {
         {k1: \"bar\", k2: [98, 97, 114]}: BorrowedItem { \
         key1: \"bar\", key2: [98, 97, 114], key3: \"bar\" }}";
 
-    assert_eq!(format!("{:?}", map), DEBUG_OUTPUT);
+    assert_eq!(format!("{map:?}"), DEBUG_OUTPUT);
     assert_eq!(fmt_debug(&map), DEBUG_OUTPUT);
 }
 
