@@ -48,6 +48,39 @@ fn debug_impls() {
     );
 }
 
+#[test]
+fn debug_impls_borrowed() {
+    let before = id_hash_map! {
+        HashBuilder;
+        BorrowedItem { key1: "a", key2: b"b0", key3: Path::new("path0") },
+        BorrowedItem { key1: "b", key2: b"b1", key3: Path::new("path1") },
+        BorrowedItem { key1: "c", key2: b"b2", key3: Path::new("path2") },
+    };
+
+    assert_eq!(
+        format!("{before:?}"),
+        r#"{"a": BorrowedItem { key1: "a", key2: [98, 48], key3: "path0" }, "c": BorrowedItem { key1: "c", key2: [98, 50], key3: "path2" }, "b": BorrowedItem { key1: "b", key2: [98, 49], key3: "path1" }}"#
+    );
+
+    #[cfg(feature = "daft")]
+    {
+        use daft::Diffable;
+
+        let after = id_hash_map! {
+            HashBuilder;
+            BorrowedItem { key1: "a", key2: b"b0", key3: Path::new("path0") },
+            BorrowedItem { key1: "c", key2: b"b3", key3: Path::new("path3") },
+            BorrowedItem { key1: "d", key2: b"b4", key3: Path::new("path4") },
+        };
+
+        let diff = before.diff(&after);
+        assert_eq!(
+            format!("{diff:?}"),
+            r#"Diff { common: {"a": IdLeaf { before: BorrowedItem { key1: "a", key2: [98, 48], key3: "path0" }, after: BorrowedItem { key1: "a", key2: [98, 48], key3: "path0" } }, "c": IdLeaf { before: BorrowedItem { key1: "c", key2: [98, 50], key3: "path2" }, after: BorrowedItem { key1: "c", key2: [98, 51], key3: "path3" } }}, added: {"d": BorrowedItem { key1: "d", key2: [98, 52], key3: "path4" }}, removed: {"b": BorrowedItem { key1: "b", key2: [98, 49], key3: "path1" }} }"#
+        );
+    }
+}
+
 #[test]
 fn with_capacity() {
     let map = IdHashMap::<TestItem, HashBuilder>::with_capacity_and_hasher(
@@ -96,7 +129,7 @@ fn test_insert_unique() {
 
     // Test that the RefMut Debug impl looks good.
     assert!(
-        format!("{:?}", e1).starts_with(
+        format!("{e1:?}").starts_with(
             r#"TestItem { key1: 5, key2: 'a', key3: "y", value: "v""#,
         ),
         "RefMut Debug impl should forward to TestItem",
@@ -414,14 +447,14 @@ fn borrowed_item() {
     fn fmt_debug(
         map: &IdHashMap<BorrowedItem<'_>, HashBuilder, Alloc>,
     ) -> String {
-        format!("{:?}", map)
+        format!("{map:?}")
     }
 
     static DEBUG_OUTPUT: &str = "{\"foo\": BorrowedItem { \
         key1: \"foo\", key2: [102, 111, 111], key3: \"foo\" }, \
         \"bar\": BorrowedItem { \
         key1: \"bar\", key2: [98, 97, 114], key3: \"bar\" }}";
-    assert_eq!(format!("{:?}", map), DEBUG_OUTPUT);
+    assert_eq!(format!("{map:?}"), DEBUG_OUTPUT);
     assert_eq!(fmt_debug(&map), DEBUG_OUTPUT);
 }
 
